@@ -2,11 +2,12 @@
 #define MAINWINDOW_H
 #include <kernelmessageswindow.h>
 #include <helpwindow.h>
-//#include <settingswindow.h>
+#include <settingsdialog.h>
 #include <QMainWindow>
 #include <aboutwindow.h>
 #include <QDebug>
 #include <QIODevice>
+#include <QSettings>
 #include <QFile>
 #include <QtGui>
 #include <QUrl>
@@ -43,7 +44,7 @@ private slots:
     void vbusOn();
     void vbusOff();
     void kernelmessages();
-  //  void settingsWindow();
+    void settingsDialog();
     void orientationChanged();
     void enumerate();
     void helpWindow();
